@@ -1,7 +1,7 @@
 package Proc::Find::Parents;
 
 our $DATE = '2018-01-17'; # DATE
-our $VERSION = '0.630'; # VERSION
+our $VERSION = '0.631'; # VERSION
 
 use 5.010001;
 use strict;
@@ -48,7 +48,7 @@ sub get_parent_processes {
         for my $p (@{ $pt->table }) {
             $proc{ $p->{pid} } = {
                 name => $p->{fname},
-                cmdline => $p->{cmdline},
+                cmdline => $p->{cmndline},
                 pid  => $p->{pid},
                 ppid => $p->{ppid},
                 uid  => $p->{uid},
@@ -93,7 +93,7 @@ Proc::Find::Parents - Find parents of a process (up to the root)
 
 =head1 VERSION
 
-This document describes version 0.630 of Proc::Find::Parents (from Perl distribution Proc-Find-Parents), released on 2018-01-17.
+This document describes version 0.631 of Proc::Find::Parents (from Perl distribution Proc-Find-Parents), released on 2018-01-17.
 
 =head1 SYNOPSIS
 
